@@ -116,7 +116,8 @@ enum VideoCaptureAPIs {
        CAP_IMAGES       = 2000,         //!< OpenCV Image Sequence (e.g. img_%02d.jpg)
        CAP_ARAVIS       = 2100,         //!< Aravis SDK
        CAP_OPENCV_MJPEG = 2200,         //!< Built-in OpenCV MotionJPEG codec
-       CAP_INTEL_MFX    = 2300          //!< Intel MediaSDK
+       CAP_INTEL_MFX    = 2300,         //!< Intel MediaSDK
+       CAP_XINE         = 2400,         //!< XINE engine (Linux)
      };
 
 /** @brief %VideoCapture generic properties identifier.
@@ -164,7 +165,12 @@ enum VideoCaptureProperties {
        CAP_PROP_IRIS          =36,
        CAP_PROP_SETTINGS      =37, //!< Pop up video/camera filter dialog (note: only supported by DSHOW backend currently. The property value is ignored)
        CAP_PROP_BUFFERSIZE    =38,
-       CAP_PROP_AUTOFOCUS     =39
+       CAP_PROP_AUTOFOCUS     =39,
+       CAP_PROP_SAR_NUM       =40, //!< Sample aspect ratio: num/den (num)
+       CAP_PROP_SAR_DEN       =41, //!< Sample aspect ratio: num/den (den)
+#ifndef CV_DOXYGEN
+       CV__CAP_PROP_LATEST
+#endif
      };
 
 
@@ -784,7 +790,7 @@ public:
     `VideoCapture -> API Backend -> Operating System -> Device Driver -> Device Hardware`
     @endcode
     The returned value might be different from what really used by the device or it could be encoded
-    using device dependant rules (eg. steps or percentage). Effective behaviour depends from device
+    using device dependent rules (eg. steps or percentage). Effective behaviour depends from device
     driver and API Backend
 
     */
